{% extends basetemplate|default:"base.html" %}
{% load django_acdhch_functions %}

{% block scriptHeader %}
  {{ block.super }}
  {% matomo %}
{% endblock scriptHeader %}

{% block imprint %}
  <div id="wrapper-footer-secondary"
       class="footer-imprint-bar p-2 text-center">
    <a href="{% url 'django_acdhch_functions:imprint' %}">Imprint | Impressum</a>
  </div>
{% endblock imprint %}
